changeset 21437:5292a483275e

octave_config_info.m: Add possible replacement functions to docstring. * octave_config_info.m: Add possible replacement functions to docstring.
author Rik <rik@octave.org>
date Fri, 11 Mar 2016 09:30:22 -0800
parents b0920076dd98
children 8b3299e12c49
files scripts/deprecated/octave_config_info.m
diffstat 1 files changed, 4 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/scripts/deprecated/octave_config_info.m	Fri Mar 11 08:37:20 2016 -0800
+++ b/scripts/deprecated/octave_config_info.m	Fri Mar 11 09:30:22 2016 -0800
@@ -20,8 +20,9 @@
 ## @deftypefn  {Built-in Function} {} octave_config_info ()
 ## @deftypefnx {Built-in Function} {} octave_config_info (@var{option})
 ##
 ## @code{octave_config_info{} is deprecated and will be removed in
 ## Octave version 4.6.
 ##
 ## Return a structure containing configuration and installation
 ## information for Octave. 
@@ -40,7 +41,7 @@
   if (! warned)
     warned = true;
     warning ("Octave:deprecated-function",
-             "octave_config_info is obsolete and will be removed from a future version of Octave, please use __octave_config_info__ instead.");
+             "octave_config_info is obsolete and will be removed from a future version of Octave, please use __have_feature__ or __octave_config_info__ instead.");
   endif
 
   if (nargin > 1)
@@ -20,8 +20,9 @@
 ## @deftypefnx {Built-in Function} {} octave_config_info (@var{option})
 ##
-## @code{octave_config_info{} is deprecated and will be removed in
-## Octave version 4.6.
+## @code{octave_config_info} is deprecated and will be removed in
+## Octave version 4.6.  Use @code{__have_feature__ (@var{option})} or
+## @code{__octave_config_info__} as a replacement.
 ##
 ## Return a structure containing configuration and installation